@@ -23,16 +23,16 @@ as.location.character <- function(x, ...) check_location(x, ...)
 as.location.location <- function(x, ...) x
 
 check_location <- function(x, ...){
-  if(is.url(x)){
+  if (is.url(x)) {
     as_location(x, "url")
   } else {
-    if(!file.exists(x)) stop("File does not exist. Create it, or fix the path.")
+    if (!file.exists(x)) stop("File does not exist. Create it, or fix the path.", call. = FALSE)
     as_location(path.expand(x), "file")
   }
 }
 
 as_location <- function(x, type){
-  structure(x, class="location", type=type)
+  structure(x, class = "location", type = type)
 }
 
 #' @export
