@@ -299,8 +299,9 @@ geojson_list.geo_list <- function(input, lat = NULL, lon = NULL, group = NULL,
 #' @export
 geojson_list.json <- function(input, lat = NULL, lon = NULL, group = NULL,
                               geometry = "point", type = "FeatureCollection", ...) {
-  
-  jsonlite::fromJSON(input, FALSE, ...)
+
+  output_list <- jsonlite::fromJSON(input, FALSE, ...)
+  as.geo_list(output_list, from = "json")
 }
 
 as.geo_list <- function(x, from) structure(x, class = "geo_list", from = from)
